@@ -138,6 +138,34 @@ class CdnClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateScdnDomain(self, request):
+        """CreateScdnDomain 用于创建 SCDN 加速域名
+
+        :param request: Request instance for CreateScdnDomain.
+        :type request: :class:`tencentcloud.cdn.v20180606.models.CreateScdnDomainRequest`
+        :rtype: :class:`tencentcloud.cdn.v20180606.models.CreateScdnDomainResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateScdnDomain", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateScdnDomainResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateScdnFailedLogTask(self, request):
         """CreateScdnFailedLogTask 用于重试创建失败的事件日志任务
 
@@ -334,6 +362,34 @@ class CdnClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeCcData(self, request):
+        """CC统计数据查询
+
+        :param request: Request instance for DescribeCcData.
+        :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeCcDataRequest`
+        :rtype: :class:`tencentcloud.cdn.v20180606.models.DescribeCcDataResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeCcData", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeCcDataResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeCdnData(self, request):
         """DescribeCdnData 用于查询 CDN 实时访问监控数据，支持以下指标查询：
 
@@ -487,6 +543,34 @@ class CdnClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeDDoSData(self, request):
+        """DDoS统计数据查询
+
+        :param request: Request instance for DescribeDDoSData.
+        :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeDDoSDataRequest`
+        :rtype: :class:`tencentcloud.cdn.v20180606.models.DescribeDDoSDataResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeDDoSData", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeDDoSDataResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeDiagnoseReport(self, request):
         """DescribeDiagnoseReport 用于获取指定报告id的内容
 
@@ -600,6 +684,34 @@ class CdnClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeEventLogData(self, request):
+        """DescribeEventLogData 用于查询事件日志统计曲线
+
+        :param request: Request instance for DescribeEventLogData.
+        :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeEventLogDataRequest`
+        :rtype: :class:`tencentcloud.cdn.v20180606.models.DescribeEventLogDataResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeEventLogData", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeEventLogDataResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeImageConfig(self, request):
         """DescribeImageConfig 用于获取域名图片优化的当前配置，支持Webp、TPG 和 Guetzli。
 
@@ -922,6 +1034,62 @@ class CdnClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeScdnBotData(self, request):
+        """获取BOT统计数据列表
+
+        :param request: Request instance for DescribeScdnBotData.
+        :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeScdnBotDataRequest`
+        :rtype: :class:`tencentcloud.cdn.v20180606.models.DescribeScdnBotDataResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeScdnBotData", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeScdnBotDataResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeScdnBotRecords(self, request):
+        """查询BOT会话记录列表
+
+        :param request: Request instance for DescribeScdnBotRecords.
+        :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeScdnBotRecordsRequest`
+        :rtype: :class:`tencentcloud.cdn.v20180606.models.DescribeScdnBotRecordsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeScdnBotRecords", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeScdnBotRecordsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeScdnConfig(self, request):
         """DescribeScdnConfig 用于查询指定 SCDN 加速域名的安全相关配置
 
@@ -950,6 +1118,34 @@ class CdnClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeScdnIpStrategy(self, request):
+        """查询在SCDN IP安全策略
+
+        :param request: Request instance for DescribeScdnIpStrategy.
+        :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeScdnIpStrategyRequest`
+        :rtype: :class:`tencentcloud.cdn.v20180606.models.DescribeScdnIpStrategyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeScdnIpStrategy", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeScdnIpStrategyResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeScdnTopData(self, request):
         """获取SCDN的Top数据
 
@@ -978,6 +1174,44 @@ class CdnClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeTopData(self, request):
+        """DescribeTopData 通过入参 Metric 和 Filter 组合不同，可以查询以下排序数据：
+
+        + 依据总流量、总请求数对访问 IP 排序，从大至小返回 TOP 100 IP
+        + 依据总流量、总请求数对访问 Refer 排序，从大至小返回 TOP 100 Refer
+        + 依据总流量、总请求数对访问 设备 排序，从大至小返回 设备类型
+        + 依据总流量、总请求数对访问 操作系统 排序，从大至小返回 操作系统
+        + 依据总流量、总请求数对访问 浏览器 排序，从大至小返回 浏览器
+
+        注意：
+        + 仅支持 90 天内数据查询，且从2021年09月20日开始有数据
+        + 本接口为beta版，尚未正式全量发布
+
+        :param request: Request instance for DescribeTopData.
+        :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeTopDataRequest`
+        :rtype: :class:`tencentcloud.cdn.v20180606.models.DescribeTopDataResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeTopData", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeTopDataResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeTrafficPackages(self, request):
         """DescribeTrafficPackages 用于查询中国境内 CDN 流量包详情。
 
@@ -1035,8 +1269,36 @@ class CdnClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeWafData(self, request):
+        """Waf统计数据查询
+
+        :param request: Request instance for DescribeWafData.
+        :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeWafDataRequest`
+        :rtype: :class:`tencentcloud.cdn.v20180606.models.DescribeWafDataResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeWafData", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeWafDataResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DisableCaches(self, request):
-        """DisableCaches 用于禁用 CDN 上指定 URL 的访问，禁用完成后，中国境内访问会直接返回 403。（接口尚在内测中，暂未全量开放使用）
+        """DisableCaches 用于禁用 CDN 上指定 URL 的访问，禁用完成后，中国境内访问会直接返回 403。（注：接口尚在内测中，暂未全量开放；封禁URL并非无限期永久封禁）
 
         :param request: Request instance for DisableCaches.
         :type request: :class:`tencentcloud.cdn.v20180606.models.DisableCachesRequest`
@@ -1343,6 +1605,146 @@ class CdnClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ListScdnTopBotData(self, request):
+        """获取Bot攻击的Top数据列表
+
+        :param request: Request instance for ListScdnTopBotData.
+        :type request: :class:`tencentcloud.cdn.v20180606.models.ListScdnTopBotDataRequest`
+        :rtype: :class:`tencentcloud.cdn.v20180606.models.ListScdnTopBotDataResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ListScdnTopBotData", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ListScdnTopBotDataResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def ListTopBotData(self, request):
+        """获取Bot攻击的Top信息
+
+        :param request: Request instance for ListTopBotData.
+        :type request: :class:`tencentcloud.cdn.v20180606.models.ListTopBotDataRequest`
+        :rtype: :class:`tencentcloud.cdn.v20180606.models.ListTopBotDataResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ListTopBotData", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ListTopBotDataResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def ListTopCcData(self, request):
+        """获取CC攻击Top数据
+
+        :param request: Request instance for ListTopCcData.
+        :type request: :class:`tencentcloud.cdn.v20180606.models.ListTopCcDataRequest`
+        :rtype: :class:`tencentcloud.cdn.v20180606.models.ListTopCcDataResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ListTopCcData", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ListTopCcDataResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def ListTopClsLogData(self, request):
+        """通过CLS日志计算Top信息。支持近7天的日志数据。
+
+        :param request: Request instance for ListTopClsLogData.
+        :type request: :class:`tencentcloud.cdn.v20180606.models.ListTopClsLogDataRequest`
+        :rtype: :class:`tencentcloud.cdn.v20180606.models.ListTopClsLogDataResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ListTopClsLogData", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ListTopClsLogDataResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def ListTopDDoSData(self, request):
+        """获取DDoS攻击Top数据
+
+        :param request: Request instance for ListTopDDoSData.
+        :type request: :class:`tencentcloud.cdn.v20180606.models.ListTopDDoSDataRequest`
+        :rtype: :class:`tencentcloud.cdn.v20180606.models.ListTopDDoSDataResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ListTopDDoSData", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ListTopDDoSDataResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ListTopData(self, request):
         """ListTopData 通过入参 Metric 和 Filter 组合不同，可以查询以下排序数据：
 
@@ -1379,6 +1781,34 @@ class CdnClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ListTopWafData(self, request):
+        """获取Waf攻击Top数据
+
+        :param request: Request instance for ListTopWafData.
+        :type request: :class:`tencentcloud.cdn.v20180606.models.ListTopWafDataRequest`
+        :rtype: :class:`tencentcloud.cdn.v20180606.models.ListTopWafDataResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ListTopWafData", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ListTopWafDataResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ManageClsTopicDomains(self, request):
         """ManageClsTopicDomains 用于管理某日志主题下绑定的域名列表。
 
@@ -1495,7 +1925,7 @@ class CdnClient(AbstractClient):
 
     def PushUrlsCache(self, request):
         """PushUrlsCache 用于将指定 URL 资源列表加载至 CDN 节点，支持指定加速区域预热。
-        默认情况下境内、境外每日预热 URL 限额为各 1000 条，每次最多可提交 20 条。
+        默认情况下境内、境外每日预热 URL 限额为各 1000 条，每次最多可提交 20 条。注意：中国境外区域预热，资源默认加载至中国境外边缘节点，所产生的边缘层流量会计入计费流量。
 
         :param request: Request instance for PushUrlsCache.
         :type request: :class:`tencentcloud.cdn.v20180606.models.PushUrlsCacheRequest`
